@@ -149,6 +149,13 @@
 	       my_check_list => { type => 'check_list',
 				  refer_to => '- hash_a + ! hash_b',
 				} ,
+	       'ordered_checklist'
+	       => { type => 'check_list',
+		    choice     => ['A' .. 'Z'],
+		    ordered => 1 ,
+		    help => { A => 'A help', E => 'E help' } ,
+		  },
+
 	       my_reference => { type => 'leaf',
 				 value_type => 'reference',
 				 refer_to => '- hash_a + ! hash_b',
